
/* Written by Morgoth DBMA, morgothdbma@o2.pl
 This is part of PgXexplorer software, Open Source
 on BSD licence, Libraries(interaces) used:
 GNU GCC, AS (all stuff needed to compile C source into executable binary)
 LibPQ-FE from PostgreSQL, GTK (GIMP Toolkit)
 written in VIM editor, ctags used, CVS used
 Currently only one author: MOrgoth DBMA
 ! THIS FILE IS BASED ON GTK EXAMPLE FROM INTERNET !
 ! MANY GTK UI FUNCTIONS ARE BASED ON SOMEBODY'S EXAMLE CODE !
 ! BUT I DON'T KNOW THEIR PERSONALITY SO SORRY !
 ! I CANNOT ADD THEM TO AUTORS, BUT THANKS FOR SUPPORT ME !
 FILE: toolbar.h */

#include "common.h"
#include "toolbar.h"
static const char * xpm_new[] = 
{
"16 16 3 1",
"       c None",
".      c #000000000000",
"X      c #FFFFFFFFFFFF",
"                ",
"   ......       ",
"   .XXX.X.      ",
"   .XXX.XX.     ",
"   .XXX.XXX.    ",
"   .XXX.....    ",
"   .XXXXXXX.    ",
"   .XXXXXXX.    ",
"   .XXXAXXX.    ",
"   .XBBXXXX.    ",
"   .XXXXXXX.    ",
"   .XXXXXXX.    ",
"   .XCCXXXX.    ",
"   .........    ",
"                ",
"                "
};

static const char * xpm_open[] = 
{
"16 16 3 1",
"       c None",
"x      c #000000000000",
".      c #eeeedddd0000",
"                ",
"                ",
"                ",
"      xxxxxx    ",
"     x......xx  ",
" xxxxxxxx....x  ",
"  x......x...x  ",
"  x......x..x   ",
"   x......x.x   ",
"   x......x.x   ",
"    x......x    ",
"    x......x    ",
"     xxxxxxxx   ",
"                ",
"                ",
"                ",
};

static const char * xpm_create[] = 
{
"16 16 2 1",
"       c None",
"c      c #FFFF55555555",
"      ccc       ",
"      ccc       ",
"      ccc       ",
"      ccc       ",
"      ccc       ",
"      ccc       ",
"      ccc       ",
"      ccc       ",
"      ccc       ",
" cc   ccc   cc  ",
"  cc  ccc  cc   ",
"   cc ccc cc    ",
"    ccccccc     ",
"     ccccc      ",
"      ccc       ",
"       c        ",
};

static const char * xpm_copy[] = 
{
"16 16 2 1",
"       c None",
"c      c #FFFFFFFF4444",
"                ",
"                ",
"          c     ",
"          cc    ",
"           cc   ",
"            cc  ",
"ccccccccccccccc ",
"cccccccccccccccc",
"ccccccccccccccc ",
"            cc  ",
"           cc   ",
"          cc    ",
"          c     ",
"                ",
"                ",
"                ",
};

static const char * xpm_save[] = 
{
"16 16 2 1",
"       c None",
"c      c #55555555FFFF",
"       c        ",
"      ccc       ",
"     ccccc      ",
"    ccccccc     ",
"   cc ccc cc    ",
"  cc  ccc  cc   ",
" cc   ccc   cc  ",
"      ccc       ",
"      ccc       ",
"      ccc       ",
"      ccc       ",
"      ccc       ",
"      ccc       ",
"      ccc       ",
"      ccc       ",
"      ccc       ",
};

static const char * xpm_drop[] = 
{
"16 16 2 1",
"       c None",
"c      c #FFFF00000000",
"cc          cccc",
"ccc        cccc ",
" ccc      cccc  ",
"  ccc     ccc   ",
"   ccc   ccc    ",
"    ccc  cc     ",
"     ccc c      ",
"      cccc      ",
"       cccc     ",
"      c  ccc    ",
"     cc   ccc   ",
"    cc     ccc  ",
"   ccc      ccc ",
"  cccc       ccc",
" cccc         cc",
"cccc           c",
};

static const char * xpm_sql[] = 
{
"16 16 2 1",
"c      c #000000000000",
"       c None",
"                ",
"                ",
"     ccccc      ",
"   cccc cccc    ",
"  ccc     ccc   ",
" ccc       ccc  ",
" ccc       ccc  ",
"ccc         ccc ",
"ccc         ccc ",
"ccc         ccc ",
" ccc   cc  ccc  ",
" ccc    cc ccc  ",
"  ccc    cccc   ",
"   cccc ccccc   ",
"     ccccc  cc  ",
"             cc ",
};

static const char * xpm_env[] = 
{
"16 16 5 1",
"       c None",
"m      c #bbbbbbbbbbbb",
"r      c #DDDD99995555",
"o      c #999999999999",
"c      c #000000000000",
"                ",
"           cccc ",
"   ccccc  coccc ",
"  cmmmc  coc    ",
" cmmcc  coc   c ",
"cmmmcc  coc  oc ",
" cmcrrc cooccc  ",
"  c ccrcooooc   ",
"     ccocccc    ",
"    ccooc       ",
" cccoocrrc      ",
"cooooc crrc     ",
" cooc  crrrc    ",
" coc    crrc    ",
"  cc     cc     ",
"                ",
};
static const char * xpm_fexec1[] = 
{
"16 16 2 1",
"       c None",
"c      c #AAAA00000000",
"       ccc      ",
"       ccc      ",
"       ccc      ",
"       ccc      ",
"       ccc      ",
"       ccc      ",
"       ccc      ",
"       ccc      ",
"       ccc      ",
"       ccc      ",
"       ccc      ",
"       ccc      ",
"                ",
"       ccc      ",
"       ccc      ",
"       ccc      ",
};
static const char * xpm_fexec2[] = 
{
"16 16 2 1",
"       c None",
"c      c #0000AAAA0000",
"       ccc      ",
"       ccc      ",
"       ccc      ",
"       ccc      ",
"       ccc      ",
"       ccc      ",
"       ccc      ",
"       ccc      ",
"       ccc      ",
"       ccc      ",
"       ccc      ",
"       ccc      ",
"                ",
"       ccc      ",
"       ccc      ",
"       ccc      ",
};
static const char * xpm_fexec3[] = 
{
"16 16 2 1",
"       c None",
"c      c #00000000AAAA",
"       ccc      ",
"       ccc      ",
"       ccc      ",
"       ccc      ",
"       ccc      ",
"       ccc      ",
"       ccc      ",
"       ccc      ",
"       ccc      ",
"       ccc      ",
"       ccc      ",
"       ccc      ",
"                ",
"       ccc      ",
"       ccc      ",
"       ccc      ",
};

static const char * xpm_about[] = 
{
"16 16 2 1",
"       c None",
"c      c #000000000000",
"                ",
"     ccccccc    ",
"    ccccccccc   ",
"    ccc   ccc   ",
"     cc   ccc   ",
"         cccc   ",
"        cccc    ",
"       ccc      ",
"       ccc      ",
"       ccc      ",
"       ccc      ",
"       ccc      ",
"       ccc      ",
"                ",
"       ccc      ",
"       ccc      ",
};

static const char * xpm_btn[] = 
{
"16 16 4 1",
"       c None",
"c      c #00000000FFFF",
"r      c #44440000FFFF",
"k      c #AAAAAAAAAAAA",
"    cccccccc    ",
"   crrrrrrrrc   ",
"  crrrrrrrrrrc  ",
" crrrrrrrrrrrrc ",
"crrrrrrrrrrrrrrc",
"crrrrrrrrrrrrrrc",
"crrkkkkkkkkkkrrc",
"crrkkkkkkkkkkrrc",
"crrkkkkkkkkkkrrc",
"crrkkkkkkkkkkrrc",
"crrrrrrrrrrrrrrc",
"crrrrrrrrrrrrrrc",
" crrrrrrrrrrrrc ",
"  crrrrrrrrrrc  ",
"   crrrrrrrrc   ",
"    cccccccc    ",
};

static const char * xpm_quit[] = 
{
"16 16 4 1",
"       c None",
"c      c #000000000000",
"r      c #FFFF00000000",
"k      c #FFFFFFFFFFFF",
"    cccccccc    ",
"   crrrrrrrrc   ",
"  crrrrrrrrrrc  ",
" crrrrrrrrrrrrc ",
"crrrrrrrrrrrrrrc",
"crrrrrrrrrrrrrrc",
"crrkkkkkkkkkkrrc",
"crrkkkkkkkkkkrrc",
"crrkkkkkkkkkkrrc",
"crrkkkkkkkkkkrrc",
"crrrrrrrrrrrrrrc",
"crrrrrrrrrrrrrrc",
" crrrrrrrrrrrrc ",
"  crrrrrrrrrrc  ",
"   crrrrrrrrc   ",
"    cccccccc    ",
};


void get_toolbar(GtkWidget* w, GtkWidget **tb);
void about_window_new();
static char *xpm_big[] = 
{
"   210   210       64            1",
". c #000100",
"# c #1b1d1b",
"a c #242f2f",
"b c #3a4042",
"c c #4f5456",
"d c #666a6c",
"e c #767b7d",
"f c #878c8e",
"g c #989c9f",
"h c #abb0b2",
"i c #bbc0c2",
"j c #cdd2d4",
"k c #dde3e5",
"l c #f0f2ef",
"m c #0d100c",
"n c #2d3738",
"o c #5c6062",
"p c #414c4d",
"q c #192324",
"r c #f9fbf7",
"s c #7e8385",
"t c #1f292a",
"u c #6e7275",
"v c #e6ebee",
"w c #d7dcdf",
"x c #c3c9cc",
"y c #b2b7ba",
"z c #a0a5a7",
"A c #8f9496",
"B c #222321",
"C c #2a2b29",
"D c #767875",
"E c #acaeab",
"F c #363735",
"G c #8a8c89",
"H c #bfc1be",
"I c #3e403d",
"J c #6f716e",
"K c #d0d2cf",
"L c #c7c9c5",
"M c #545653",
"N c #676865",
"O c #9b9d9a",
"P c #131513",
"Q c #55595c",
"R c #e0e2df",
"S c #828481",
"T c #2a2e30",
"U c #f4f7f4",
"V c #a4a6a3",
"W c #5f615e",
"X c #494b48",
"Y c #d8dad7",
"Z c #e9ebe8",
"0 c #929491",
"1 c #070a05",
"2 c #1d2727",
"3 c #b4b6b3",
"4 c #34383a",
"5 c #484c4e",
"6 c #fcfefb",
"7 c #262827",
"8 c #444543",
"9 c #3f4547",
/* pixels */
"666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666",
"666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666",
"666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666",
"666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666",
"666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666",
"66666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666UYizAfffzyKU6666666666666666666666666666666666666666666666666",
"6666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666Uie5tqqqqqqqqqqtQgl6666666666666666666666666666666666666666666666",
"66666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666xuaqqqqqqqqqqqqqqqqqaAr66666666666666666666666666666666666666666666",
"666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666icqqqqqqqqqqqqqqqqqqqqqqcl6666666666666666666666666666666666666666666",
"6666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666YQqqqqqqqqqqqqqqqqqqqqqqqqqcr666666666666666666666666666666666666666666",
"66666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666rA2qqqqqqqqqqqqqqqqqqqqqqqqqqqA666666666666666666666666666666666666666666",
"6666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666Zzuc55ogZ666666666666666666666666666ZQqqqqqqqqqqqqqqqqqqqqqqqqqqqqq4r66666666666666666666666666666666666666666",
"66666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666joqqqqqqqq7g6666666666666666666666666wbqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqi66666666666666666666666666666666666666666",
"666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666reqqqqqqqqqqqqs66666666666666666666666KTqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqA66666666666666666666666666666666666666666",
"66666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666lcqqqqqqqqqqqqqqy666666666666666666666jTqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqu66666666666666666666666666666666666666666",
"6666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666rQqqqqqqqqqqqqqqqbr6666666666666666666k4qqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqu66666666666666666666666666666666666666666",
"6666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666fqqqqqqqqqqqqqqqqqi666666666666666666U5qqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqe66666666666666666666666666666666666666666",
"666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666k2qqqqqqqqqqqqqqqqqu666666666666666666uqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqA66666666666666666666666666666666666666666",
"666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666uqqqqqqqqqqqqqqqqqqb66666666666666666yqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqi66666666666666666666666666666666666666666",
"66666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666vtqqqqqqqqqqqqqqqqqq2U666666666666666l4qqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqq2Z66666666666666666666666666666666666666666",
"66666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666zqqqqqqqqqqqqqqqqqqqqk666666666666666eqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqq5666666666666666666666666666666666666666666",
"66666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666dqqqqqqqqqqqqqqqqqqqqK66666666666666w2qqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqA666666666666666666666666666666666666666666",
"66666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666nqqqqqqqqqqqqqqqqqqqqK66666666666666dqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqR666666666666666666666666666666666666666666",
"66666666666666666666666666666666666666666666666666666666666666666666666ljxR6666666666666666ZqqqqqqqqqqqqqqqqqqqqqK6666666666666Rqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqo6666666666666666666666666666666666666666666",
"66666666666666666666666666666666666666666666666666666666666666666666ryo2qqqpy66666666666666xqqqqqqqqqqqqqqqqqqqqqw6666666666666eqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqi6666666666666666666666666666666666666666666",
"6666666666666666666666666666666666666666666666666666666666666666666jpqqqqqqqqf6666666666666hqqqqqqqqqqqqqqqqqqqqql666666666666Uaqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqq566666666666666666666666666666666666666666666",
"666666666666666666666666666666666666666666666666666666666666666666htqqqqqqqqqqz666666666666hqqqqqqqqqqqqqqqqqqqqT6666666666666hqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqy66666666666666666666666666666666666666666666",
"66666666666666666666666666666666666666666666666666666666666666666y2qqqqqqqqqqq7R66666666666hqqqqqqqqqqqqqqqqqqqq56666666666666oqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqQ666666666666666666666666666666666666666666666",
"6666666666666666666666666666666666666666666666666666666666666666Raqqqqqqqqqqqqqu66666666666hqqqqqqqqqqqqqqqqqqqqu666666666666U7qqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqj666666666666666666666666666666666666666666666",
"6666666666666666666666666666666666666666666666666666666666666666uqqqqqqqqqqqqqq2Z6666666666hqqqqqqqqqqqqqqqqqqqqz666666666666iqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqe6666666666666666666666666666666666666666666666",
"666666666666666666666666666666666666666666666666666666666666666Z2qqqqqqqqqqqqqqqg6666666666xqqqqqqqqqqqqqqqqqqqqw666666666666fqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqq4l6666666666666666666666666666666666666666666666",
"666666666666666666666666666666666666666666666666666666666666666zqqqqqqqqqqqqqqqqo6666666666Rqqqqqqqqqqqqqqqqqqq4r666666666666Qqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqi66666666666666666666666666666666666666666666666",
"666666666666666666666666666666666666666666666666666666666666666uqqqqqqqqqqqqqqqqar6666666666aqqqqqqqqqqqqqqqqqqu66666666666664qqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqe666666666666666666666666666666666666666666666666",
"666666666666666666666666666666666666666666666666666666666666666cqqqqqqqqqqqqqqqqqY6666666666cqqqqqqqqqqqqqqqqqqy666666666666vqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqpU666666666666666666666666666666666666666666666666",
"6666666666666666666666666666666666666666666666666666666666666669qqqqqqqqqqqqqqqqqh6666666666sqqqqqqqqqqqqqqqqqTU666666666666YqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqTY6666666666666666666666666666666666666666666666666",
"6666666666666666666666666666666666666666666666666666666666666669qqqqqqqqqqqqqqqqqA6666666666iqqqqqqqqqqqqqqqqqe6666666666666iqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqy66666666666666666666666666666666666666666666666666",
"6666666666666666666666666666666666666666666666666666666666666669qqqqqqqqqqqqqqqqqs6666666666UaqqqqqqqqqqqqqqqqK6666666666666iqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqA666666666666666666666666666666666666666666666666666",
"666666666666666666666666666666666666666666666666666666666666666oqqqqqqqqqqqqqqqqqd66666666666dqqqqqqqqqqqqqqqQ66666666666666iqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqe6666666666666666666666666666666666666666666666666666",
"666666666666666666666666666666666666666666666666666666666666666eqqqqqqqqqqqqqqqqqd66666666666iqqqqqqqqqqqqqqqx66666666666666iqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqor6666666666666666666666666666666666666666666666666666",
"666666666666666666666666666666666666666666666666666666666666666zqqqqqqqqqqqqqqqqqd6666666666669qqqqqqqqqqqqqQ666666666666666iqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqcr66666666666666666666666666666666666666666666666666666",
"666666666666666666666666666666666666666666666666666666666666666Rqqqqqqqqqqqqqqqqqd666666666666hqqqqqqqqqqqq2w666666666666666Yqqqqqqqqqqqqqqqqqqqqqqqqqqqqqcl666666666666666666666666666666666666666666666666666666",
"6666666666666666666666666666666666666666666666666666666666666666bqqqqqqqqqqqqqqqqe6666666666666Qqqqqqqqqqqqf6666666666666666U2qqqqqqqqqqqqqqqqqqqqqqqqqqqQl6666666666666666666666666666666666666666666666666666666",
"6666666666666666666666666666666666666666666666666666666666666666fqqqqqqqqqqqqqqqqf6666666666666waqqqqqqqqqcr666666666666666665qqqqqqqqqqqqqqqqqqqqqqqqqqdr66666666666666666666666666666666666666666666666666666666",
"66666666666666666666666666666666666666666666666LfuAK666666666666wqqqqqqqqqqqqqqqqz66666666666666y2qqqqqqqbZ666666666666666666eqqqqqqqqqqqqqqqqqqqqqqqqqer666666666666666666666666666666666666666666666666666666666",
"666666666666666666666666666666666666666666666j5qqqqqdl66666666666oqqqqqqqqqqqqqqqi666666666666666h7qqqqq5Z6666666666666666666iqqqqqqqqqqqqqqqqqqqqqqq2z66666666666666666666666666666666666666666666666666666666666",
"66666666666666666666666666666666666666666666g2qqqqqqq9v6666666666xqqqqqqqqqqqqqqqZ6666666666666666RuT2bgr66666666666666666666rbqqqqqqqqqqqqqqqqqqqqq4x666666666666666666666666666666666666666666666666666666666666",
"6666666666666666666666666666666666666666666gqqqqqqqqqqcr6666666666oqqqqqqqqqqqqq46666666666666666666rl666666666666666666666666zqqqqqqqqqqqqqqqqqqqqoZ6666666666666666666666666666666666666666666666666666666666666",
"666666666666666666666666666666666666666666x2qqqqqqqqqqqA6666666666k7qqqqqqqqqqqqu666666666666666666666666666666666666666666666r9qqqqqqqqqqqqqqqqqTz666666666666666666666666666666666666666666666666666666666666666",
"6666666666666666666666666666666666666666665qqqqqqqqqqqqtR6666666666gqqqqqqqqqqqqy6666666666666666666666666666666666666666666666Yaqqqqqqqqqqqqqqquv6666666666666666666666666666666666666666666666666666666666666666",
"66666666666666666666666666666666666666666jqqqqqqqqqqqqqqe66666666666oqqqqqqqqqqnr66666666666666666666666666666666666666666666666iTqqqqqqqqqqqqoK666666666666666666666666666666666666666666666666666666666666666666",
"66666666666666666666666666666666666666666Aqqqqqqqqqqqqqqtv6666666666lpqqqqqqqqqf6666666666666666666666666666666666666666666666666RoqqqqqqqqneY66666666666666666666666666666666666666666666666666666666666666666666",
"66666666666666666666666666666666666666666dqqqqqqqqqqqqqqqA66666666666v5qqqqqqq4l666666666666666666666666666666666666666666666666666YAdcQdAxr6666666666666666666666666666666666666666666666666666666666666666666666",
"66666666666666666666666666666666666666666cqqqqqqqqqqqqqqqp666666666666luqqqqqax66666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666",
"66666666666666666666666666666666666666666oqqqqqqqqqqqqqqqqR6666666666666xdnaoj666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666",
"66666666666666666666666666666666666666666uqqqqqqqqqqqqqqqqz6666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666",
"66666666666666666666666666666666666666666gqqqqqqqqqqqqqqqqu6666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666",
"66666666666666666666666666666666666666666jqqqqqqqqqqqqqqqq96666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666",
"66666666666666666666666666666666666666666rbqqqqqqqqqqqqqqqtr666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666",
"666666666666666666666666666666666666666666fqqqqqqqqqqqqqqqqk6666666666666666666666666666666666666666666666URxyzgffseeffAzyxRU6666666666666666666666666666666666666666666666666666666666666666666666666666666666666",
"666666666666666666666666666666666666666666Ztqqqqqqqqqqqqqqqx6666666666666666666666666666666666666666kyAucn2qqqqqqqqqqqqqqqqq2bofyZ66666666666666666666666666666666666666666666666666666666666666666666666666666666",
"6666666666666666666666666666666666666666666sqqqqqqqqqqqqqqqi66666666666666666666666666666666666lifQaqqqqqqqqqqqqqqqqqqqqqqqqqqqqqq9sxr6666666666666666666666666666666666666666666666666666666666666666666666666666",
"6666666666666666666666666666666666666666666l4qqqqqqqqqqqqqqi6666666666666666666666666666666Uisp2qqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqq4sw66666666666666666666666666666666666666666666666666666666666666666666666666",
"66666666666666666666666666666666666666666666yqqqqqqqqqqqqqqi6666666666666666666666666666vhd7qqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqdY666666666666666666666666666666666666666666666666666666666666666666666666",
"666666666666666666666666666666666666666666666eqqqqqqqqqqqqqx6666666666666666666666666UhotqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqquZ6666666666666666666666666666666666666666666666666666666666666666666666",
"666666666666666666666666666666666666666666666rcqqqqqqqqqqqqk66666666666666666666666jeaqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqq4i666666666666666666666666666666666666666666666666666666666666666666666",
"6666666666666666666666666666666666666666666666l9qqqqqqqqqqTr66666666666666666666rhcqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqA66666666666666666666666666666666666666666666666666666666666666666666",
"66666666666666666666666666666666666666666666666Zcqqqqqqqqqd6666666666666666666Ugbqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqf6666666666666666666666666666666666666666666666666666666666666666666",
"666666666666666666666666666666666666666666666666Uuqqqqqqqqi66666666666666666rg4qqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqz666666666666666666666666666666666666666666666666666666666666666666",
"66666666666666666666666666666666666666666666666666y4qqqqqd66666666666666666h4qqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqq7R66666666666666666666666666666666666666666666666666666666666666666",
"666666666666666666666666666666666666666666666666666rhd5cgr666666666666666K5qqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqo66666666666666666666666666666666666666666666666666666666666666666",
"66666666666666666666666666666666666666666666666666666666666666666666666leqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqj6666666666666666666666666666666666666666666666666666666666666666",
"6666666666666666666666666666666666666666666666666666666666666666666666inqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqe6666666666666666666666666666666666666666666666666666666666666666",
"66666666666666666666666666666666666666666666666666666666666666666666Usqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqb6666666666666666666666666666666666666666666666666666666666666666",
"6666666666666666666666666666666666666666666666666666666666666666666R5qqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqZ666666666666666666666666666666666666666666666666666666666666666",
"666666666666666666666666666666666666666666666666666666666666666666xnqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqj666666666666666666666666666666666666666666666666666666666666666",
"66666666666666666666666666666666666666666666666666666666666666666z2qqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqi666666666666666666666666666666666666666666666666666666666666666",
"6666666666666666666666666666666666666666666666666666666666666666fqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqy666666666666666666666666666666666666666666666666666666666666666",
"666666666666666666666666666666666666666666666666666666666666666eqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqx666666666666666666666666666666666666666666666666666666666666666",
"66666666666666666666666666666666666666666666666666666666666666sqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqY666666666666666666666666666666666666666666666666666666666666666",
"6666666666666666666666666666666666666666666666666666666666666Aqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqq2U666666666666666666666666666666666666666666666666666666666666666",
"666666666666666666666666666666666666666666666666666666666666hqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqq56666666666666666666666666666666666666666666666666666666666666666",
"66666666666666666666666666666666666666666666666666666666666jtqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqf6666666666666666666666666666666666666666666666666666666666666666",
"6666666666666666666666666666666666666666666666666666666666Znqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqj6666666666666666666666666666666666666666666666666666666666666666",
"6666666666666666666666666666666666666666666666666666666666dqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqc66666666666666666666666666666666666666666666666666666666666666666",
"666666666666666666666666666666666666666666666666666666666hqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqy66666666666666666666666666666666666666666666666666666666666666666",
"66666666666666666666666666666666666666666666666666666666ZTqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqc666666666666666666666666666666666666666666666666666666666666666666",
"66666666666666666666666666666666666666666666666666666666eqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqq2K666666666666666666666666666666666666666666666666666666666666666666",
"6666666666666666666666666666666666666666666666666666666Y2qqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqs6666666666666666666666666666666666666666666666666666666666666666666",
"6666666666666666666666666666666666666666666666666666666dqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqcr6666666666666666666666666666666666666666666666666666666666666666666",
"666666666666666666666666666666666666666666666666666666k2qqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqq4k66666666666666666666666666666666666666666666666666666666666666666666",
"666666666666666666666666666666666666666666666666666666sqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqaK666666666666666666666666666666666666666666666666666666666666666666666",
"66666666666666666666666666666666666666666666666666666rnqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqti6666666666666666666666666666666666666666666666666666666666666666666666",
"66666666666666666666666666666666666666666666666666666yqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqti66666666666666666666666666666666666666666666666666666666666666666666666",
"66666666666666666666666666666666666666666666666666666uqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqti666666666666666666666666666666666666666666666666666666666666666666666666",
"6666666666666666666666666666666666666666666666666666r4qqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqTK6666666666666666666666666666666666666666666666666666666666666666666666666",
"6666666666666666666666666666666666666666666666666666Yqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqq9k66666666666666666666666666666666666666666666666666666666666666666666666666",
"6666666666666666666666666666666666666666666666666666zqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqov666666666666666666666666666666666666666666666666666666666666666666666666666",
"6666666666666666666666666666666666666666666666666666eqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqq2fr6666666666666666666666666666666666666666666666666666666666666666666666666666",
"6666666666666666666666666666666666666666666666666666cqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqq4i666666666666666666666666666666666666666666666666666666666666666666666666666666",
"66666666666666666666666666666666666666666666666666664qqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqoZ6666666666666666666666666666666666666666666666666666666666666666666666666666666",
"66666666666666666666666666666666666666666666666666662qqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqq7z666666666666666666666666666666666666666666666666666666666666666666666666666666666",
"666666666666666666666666666666666666666666666666666lqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqcw6666666666666666666666666666666666666666666666666666666666666666666666666666666666",
"666666666666666666666666666666666666666666666666666Zqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqq7gr66666666666666666666666666666666666666666666666666666666666666666666666666666666666",
"666666666666666666666666666666666666666666666666666ZqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqQR6666666666666666666666666666666666666666666666666666666666666666666666666666666666666",
"666666666666666666666666666666666666666666666666666ZqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqTz666666666666666666666666666666666666666666666666666666666666666666666666666666666666666",
"666666666666666666666666666666666666666666666666666U2qqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqquZ6666666666666666666666666666666666666666666666666666666666666666666666666666666666666666",
"66666666666666666666666666666666666666666666666666662qqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqbi666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666",
"6666666666666666666666666666666666666666666666666666bqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqtfU6666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666",
"6666666666666666666666666666666666666666666666666666QqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqoR666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666",
"6666666666666666666666666666666666666666666666666666eqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqq4h66666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666",
"6666666666666666666666666666666666666666666666666666gqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqel666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666",
"6666666666666666666666666666666666666666666666666666xqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqq5j66666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666",
"6666666666666666666666666666666666666666666666666666l2qqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqtAr666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666",
"66666666666666666666666666666666666666666666666666666cqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqcY66666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666",
"66666666666666666666666666666666666666666666666666666fqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqq2Ar666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666",
"66666666666666666666666666666666666666666666666666666Lqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqq9j66666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666",
"66666666666666666666666666666666666666666666666666666rTqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqul666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666",
"666666666666666666666666666666666666666666666666666666eqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqq2z66666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666",
"666666666666666666666666666666666666666666666666666666iqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqnL666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666",
"666666666666666666666666666666666666666666666666666666r4qqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqbY6666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666",
"6666666666666666666666666666666666666666666666666666666Aqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqbk6666666666666666666666666666666ZigsuooooeAyZ666666666666666666666666666666666666666666666666666666666666666666",
"6666666666666666666666666666666666666666666666666666666v2qqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqq4k6666666666666666666666666666vhu4qqqqqqqqqqqqqchr666666666666666666666666666666666666666666666666666666666666666",
"66666666666666666666666666666666666666666666666666666666uqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqtj666666666666666666666666666io2qqqqqqqqqqqqqqqqqq5R66666666666666666666666666666666666666666666666666666666666666",
"66666666666666666666666666666666666666666666666666666666jqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqg66666666666666666666666666y5qqqqqqqqqqqqqqqqqqqqqq4R6666666666666666666666666666666666666666666666666666666666666",
"666666666666666666666666666666666666666666666666666666666oqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqq9r666666666666666666666666voqqqqqqqqqqqqqqqqqqqqqqqqqo6666666666666666666666666666666666666666666666666666666666666",
"666666666666666666666666666666666666666666666666666666666Kqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqh666666666666666666666666wnqqqqqqqqqqqqqqqqqqqqqqqqqqqR666666666666666666666666666666666666666666666666666666666666",
"6666666666666666666666666666666666666666666666666666666666dqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqTr66666666666666666666666v4qqqqqqqqqqqqqqqqqqqqqqqqqqqqy666666666666666666666666666666666666666666666666666666666666",
"6666666666666666666666666666666666666666666666666666666666w2qqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqo666666666666666666666666sqqqqqqqqqqqqqqqqqqqqqqqqqqqqqz666666666666666666666666666666666666666666666666666666666666",
"66666666666666666666666666666666666666666666666666666666666sqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqe666666666666666666666666bqqqqqqqqqqqqqqqqqqqqqqqqqqqqqi666666666666666666666666666666666666666666666666666666666666",
"66666666666666666666666666666666666666666666666666666666666l4qqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqe6666666666666666666666664qqqqqqqqqqqqqqqqqqqqqqqqqqqqqZ666666666666666666666666666666666666666666666666666666666666",
"666666666666666666666666666666666666666666666666666666666666hqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqc666666666666666666666666pqqqqqqqqqqqqqqqqqqqqqqqqqqqqb6666666666666666666666666666666666666666666666666666666666666",
"6666666666666666666666666666666666666666666666666666666666666oqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqtl66666666666666666666666cqqqqqqqqqqqqqqqqqqqqqqqqqqqqe6666666666666666666666666666666666666666666666666666666666666",
"6666666666666666666666666666666666666666666666666666666666666kTqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqg66666666666666666666666cqqqqqqqqqqqqqqqqqqqqqqqqqqqqy6666666666666666666666666666666666666666666666666666666666666",
"66666666666666666666666666666666666666666666666666666666666666hqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqnl66666666666666666666669qqqqqqqqqqqqqqqqqqqqqqqqqqqaU6666666666666666666666666666666666666666666666666666666666666",
"666666666666666666666666666666666666666666666666666666666666666uqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqd666666666666666666666rtqqqqqqqqqqqqqqqqqqqqqqqqqqqu66666666666666666666666666666666666666666666666666666666666666",
"666666666666666666666666666666666666666666666666666666666666666l9qqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqA66666666666666666666xqqqqqqqqqqqqqqqqqqqqqqqqqqqqx66666666666666666666666666666666666666666666666666666666666666",
"6666666666666666666666666666666666666666666666666666666666666666Yaqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqz6666666666666666666eqqqqqqqqqqqqqqqqqqqqqqqqqqqp666666666666666666666666666666666666666666666666666666666666666",
"66666666666666666666666666666666666666666666666666666666666666666hqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqg66666666666666666Zaqqqqqqqqqqqqqqqqqqqqqqqqqqqh666666666666666666666666666666666666666666666666666666666666666",
"666666666666666666666666666666666666666666666666666666666666666666fqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqer666666666666666uqqqqqqqqqqqqqqqqqqqqqqqqqqqbr666666666666666666666666666666666666666666666666666666666666666",
"6666666666666666666666666666666666666666666666666666666666666666666uqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqq5R6666666666666zqqqqqqqqqqqqqqqqqqqqqqqqqqqqh6666666666666666666666666666666666666666666666666666666666666666",
"6666666666666666666666666666666666666666666666666666666666666666666roqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqq7Al666666666rfqqqqqqqqqqqqqqqqqqqqqqqqqqqqc66666666666666666666666666666666666666666666666666666666666666666",
"66666666666666666666666666666666666666666666666666666666666666666666l5qqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqnfj66666ry5qqqqqqqqqqqqqqqqqqqqqqqqqqqq2K66666666666666666666666666666666666666666666666666666666666666666",
"666666666666666666666666666666666666666666666666666666666666666666666lpqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqq4Quucaqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqs666666666666666666666666666666666666666666666666666666666666666666",
"6666666666666666666666666666666666666666666666666666666666666666666666Zpqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqq5U666666666666666666666666666666666666666666666666666666666666666666",
"66666666666666666666666666666666666666666666666666666666666666666666666l5qqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqtY6666666666666666666666666666666666666666666666666666666666666666666",
"666666666666666666666666666666666666666666666666666666666666666666666666lQqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqh66666666666666666666666666666666666666666666666666666666666666666666",
"6666666666666666666666666666666666666666666666666666666666666666666666666Udqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqs666666666666666666666666666666666666666666666666666666666666666666666",
"666666666666666666666666666666666666666666666666666666666666666666666666666fqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqdr666666666666666666666666666666666666666666666666666666666666666666666",
"6666666666666666666666666666666666666666666666666666666666666666666666666666h7qqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqQU6666666666666666666666666666666666666666666666666666666666666666666666",
"66666666666666666666666666666666666666666666666666666666666666666666666666666YbqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqQU66666666666666666666666666666666666666666666666666666666666666666666666",
"666666666666666666666666666666666666666666666666666666666666666666666666666666luqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqQU666666666666666666666666666666666666666666666666666666666666666666666666",
"66666666666666666666666666666666666666666666666666666666666666666666666666666666hTqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqur6666666666666666666666666666666666666666666666666666666666666666666666666",
"666666666666666666666666666666666666666666666666666666666666666666666666666666666Zoqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqq2A666666666666666666666666666666666666666666666666666666666666666666666666666",
"66666666666666666666666666666666666666666666666666666666666666666666666666666666666y4qqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqni6666666666666666666666666666666666666666666666666666666666666666666666666666",
"666666666666666666666666666666666666666666666666666666666666666666666666666666666666lftqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqQZ66666666666666666666666666666666666666666666666666666666666666666666666666666",
"66666666666666666666666666666666666666666666666666666666666666666666666666666666666666Ru2qqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqaz6666666666666666666666666666666666666666666666666666666666666666666666666666666",
"6666666666666666666666666666666666666666666666666666666666666666666666666666666666666666wu2qqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqquv66666666666666666666666666666666666666666666666666666666666666666666666666666666",
"666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666RsTqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqQj6666666666666666666666666666666666666666666666666666666666666666666666666666666666",
"66666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666UhQqqqqqqqqqqqqqqqqqqqqqqqqqqqq2ox666666666666666666666666666666666666666666666666666666666666666666666666666666666666",
"66666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666ZgQ2qqqqqqqqqqqqqqqqqqqqqq4fR66666666666666666666666666666666666666666666666666666666666666666666666666666666666666",
"66666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666vysctqqqqqqqqqqqqqq25fjr6666666666666666666666666666666666666666666666666666666666666666666666666666666666666666",
"666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666rYygedo55pQdszxl66666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666",
"666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666",
"666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666",
"666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666",
"666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666",
"666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666",
"666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666",
"666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666",
"666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666",
"666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666",
"666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666",
"666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666",
"666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666",
"666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666",
"666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666",
"666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666",
"6666666666666666666666666666666666666666666666666666lLVOOEYr6666666666666666666666666666666666666666ULVOO3Y6666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666",
"6666666666666666666666666666666666666666666666666lGF1......PJR6666663PPE666666666660PPPPU666666666LM1......#NY666666666666SPPL6666666666MPPU6666666IPPPPPPPPPPPPPPPF6666666666666666666666666666666666666666666666",
"66666666666666666666666666666666666666666666666rGm...........1Sr6666E..mY6666666666G....U6666666rN...........1Dr6666666666X..D666666666l1..L6666666C...............B6666666666666666666666666666666666666666666666",
"6666666666666666666666666666666666666666666666l8...............L6666E...Cl666666666G....U666666UI..............Xr666666666P..B666666666V...G6666666C...............B6666666666666666666666666666666666666666666666",
"666666666666666666666666666666666666666666666lF......17IF1....I66666E....M666666666G....U666666M.....17IFm......W66666666R....K66666666M...W6666666C...............B6666666666666666666666666666666666666666666666",
"666666666666666666666666666666666666666666666X.....BOl666lVF..L66666E.....G66666666G....U66666O.....NR666r3C.....E6666666E....S6666666rm...B6666666C...#LLLLLLLLLLLK6666666666666666666666666666666666666666666666",
"66666666666666666666666666666666666666666666O.....WU66666666VW666666E.....1H6666666G....U6666lm....06666666U8....Br666666D....C66666663....1l666666C...B6666666666666666666666666666666666666666666666666666666666",
"6666666666666666666666666666666666666666666U#....Mr66666666666666666E......PR666666G....U6666S....M666666666lP....36666668.....Y666666N.....H666666C...B6666666666666666666666666666666666666666666666666666666666",
"6666666666666666666666666666666666666666666O....Pl666666666666666666E.......Fr66666G....U6666B....Y6666666666G....W666666P.....S66666rP.....G666666C...B6666666666666666666666666666666666666666666666666666666666",
"66666666666666666666666666666666666666666668....G6666666666666666666E........N66666G....U666K....I66666666666R....#66666R......F66666H......M666666C...B6666666666666666666666666666666666666666666666666666666666",
"666666666666666666666666666666666666666666r1...1Z6666666666666666666E.........O6666G....U6660....S666666666666B....Z6666E.......R6666J......B666666C...B6666666666666666666666666666666666666666666666666666666666",
"666666666666666666666666666666666666666666K....F66666666666666666666E....8....1L666G....U666N....3666666666666M....L6666D.......G6666B.......Z66666C...mDDDDDDDDL6666666666666666666666666666666666666666666666666",
"666666666666666666666666666666666666666666E....N66666666666666666666E....H8....#Z66G....U666X....K666666666666N....E66668.......I666K........366666C............06666666666666666666666666666666666666666666666666",
"666666666666666666666666666666666666666666O....D66666666WFFFFFFFG666E....HZ#....8r6G....U666F....Y666666666666D....V6666m...B...1Z66S...Pm...S66666C............06666666666666666666666666666666666666666666666666",
"666666666666666666666666666666666666666666O....G66666666F.......J666E....H6L1....D6G....U666F....Y666666666666D....E666R....0#...066C...JI...X66666C............06666666666666666666666666666666666666666666666666",
"666666666666666666666666666666666666666666V....D66666666F.......J666E....H660.....EG....U666I....Y666666666666N....E666E....LJ...86R....LJ...#66666C...mSSSSSSSSL6666666666666666666666666666666666666666666666666",
"6666666666666666666666666666666666666666663....W66666666F.......J666E....H666M....mW....U666M....H666666666666M....L666D...1UK...1ZG...C6V....R6666C...B6666666666666666666666666666666666666666666666666666666666",
"666666666666666666666666666666666666666666K....C66666666KHHE....J666E....H666lC.........U666D....O666666666666C....R6668...F66C...OI...S6K....E6666C...B6666666666666666666666666666666666666666666666666666666666",
"666666666666666666666666666666666666666666r1...1R6666666666R....J666E....H6666Y1........U666O....N66666666666Z1...P666rP...N66G...F1...R6r1...D6666C...B6666666666666666666666666666666666666666666666666666666666",
"6666666666666666666666666666666666666666666X....D6666666666R....J666E....H66666V........U666Y....#66666666666O....M666R....O66R.......I666F...86666C...B6666666666666666666666666666666666666666666666666666666666",
"6666666666666666666666666666666666666666666V....1Y666666666R....J666E....H666666J.......U6666B....3666666666rB....E666E....L666I......O666N...P6666C...B6666666666666666666666666666666666666666666666666666666666",
"6666666666666666666666666666666666666666666U#....CZ66666666R....J666E....H666666rF......U6666S....CU66666666J....#r666D...1r666O.....1l666O....R666C...B6666666666666666666666666666666666666666666666666666666666",
"66666666666666666666666666666666666666666666V.....BH6666666V....J666E....H6666666RP.....U6666Zm....Xl66666rD.....066668...F6666l1....M6666K....V666C...B6666666666666666666666666666666666666666666666666666666666",
"666666666666666666666666666666666666666666666M......IG3LLOI.....J666E....H66666666H.....U66666G.....#GHL3D#.....I66666m...N66666M....36666r1...D666C...mNNNNNNNNNNND6666666666666666666666666666666666666666666666",
"666666666666666666666666666666666666666666666lF.................J666E....H666666666S....U66666rX...............BZ6666R....O666663...#r66666C...I666C...............B6666666666666666666666666666666666666666666666",
"6666666666666666666666666666666666666666666666lM...............FY666E....H6666666666X...U666666U8.............FR66666V....K66666r#..J666666W...mr66C...............B6666666666666666666666666666666666666666666666",
"666666666666666666666666666666666666666666666666VB...........IE66666E....H6666666666lB..U6666666rGm.........PGr666666D...1r666666J..K6666660....Y66C...............B6666666666666666666666666666666666666666666666",
"6666666666666666666666666666666666666666666666666rHJI#mm#FNOR6666666KDDDDR66666666666LB#r666666666lOMCP1#FWEl66666666ODDDG6666666K#I6666666YDDDDK66GDDDDDDDDDDDDDDDG6666666666666666666666666666666666666666666666",
"666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666",
"666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666",
"666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666",
"666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666",
"666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666"
};

int about_clback(GtkWidget* w, gpointer d)
{
 debug("%s:%d", __FILE__,__LINE__);
 gtk_main_quit();
 return FALSE;
}

void about_window_new()
{
 GtkWidget* window, *table, *button, *label, *pix, *bhbox, *blabel;
 GdkPixmap* pix_new;
 GtkStyle *style;
 GdkColormap* gcm;
 GdkBitmap *mask;
 debug("%s:%d", __FILE__,__LINE__);
 window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
 gtk_window_set_modal(GTK_WINDOW(window), 1);
 gtk_widget_set_usize (GTK_WIDGET(window), 400, 300);
 gtk_container_set_border_width(GTK_CONTAINER(window), 10);
 style = gtk_widget_get_style(window);
 gcm = gdk_colormap_get_system();
 blabel = gtk_label_new("Done!");
 label = gtk_label_new("written by Morgoth DBMA\n+48693582014\nmorgothdbma@o2.pl");
 button = gtk_button_new();
 pix_new = gdk_pixmap_colormap_create_from_xpm_d
	 (window->window,gcm,&mask,&style->bg[GTK_STATE_NORMAL],(gchar **)xpm_btn);
 pix = gtk_pixmap_new(pix_new, mask);
 gtk_widget_show(pix);
 bhbox = gtk_hbox_new (FALSE, 1);
 gtk_container_border_width (GTK_CONTAINER (bhbox), 2);
 gtk_widget_show (bhbox);
 gtk_container_add(GTK_CONTAINER(button), bhbox);
 gtk_container_add(GTK_CONTAINER(bhbox),  blabel);
 gtk_container_add(GTK_CONTAINER(bhbox),  pix);
 gtk_widget_show(blabel);
 table = gtk_table_new (2, 2, FALSE);
 gtk_container_set_border_width(GTK_CONTAINER(table), 5);
 pix_new = gdk_pixmap_colormap_create_from_xpm_d
	 (window->window,gcm,&mask,&style->bg[GTK_STATE_NORMAL],(gchar **)xpm_big);
 pix = gtk_pixmap_new(pix_new, mask);
 gtk_widget_show(pix);
 gtk_table_attach (GTK_TABLE (table), pix, 0, 2, 0, 1,
		 GTK_FILL | GTK_EXPAND,GTK_FILL | GTK_EXPAND | GTK_SHRINK, 0, 0);
 gtk_table_attach (GTK_TABLE (table), label,  0, 1, 1, 2, GTK_FILL, GTK_FILL, 0, 0);
 gtk_table_attach (GTK_TABLE (table), button, 1, 2, 1, 2, GTK_FILL, GTK_FILL, 0, 0);
 gtk_widget_show(button);
 gtk_widget_show(label);
 gtk_container_add(GTK_CONTAINER(window), table);
 gtk_widget_show (table);
 gtk_widget_grab_focus(button);
 gtk_signal_connect(GTK_OBJECT(window), "delete_event", GTK_SIGNAL_FUNC(about_clback), NULL);
 gtk_signal_connect(GTK_OBJECT(button), "clicked", GTK_SIGNAL_FUNC(about_clback), NULL);
 gtk_window_set_title(GTK_WINDOW(window), "PgXexplorer version 0.14 alpha");
 gtk_widget_show(window);
 gtk_main();
 gtk_widget_destroy(window);
}

void get_toolbar(GtkWidget* w, GtkWidget **tb)
{
 GdkPixmap* pix_new;
 GdkBitmap *mask;
 GtkStyle *style;
 GtkWidget* pix;
 GdkColormap* gcm;
 debug("%s:%d", __FILE__,__LINE__);
 *tb = gtk_toolbar_new(GTK_ORIENTATION_HORIZONTAL, GTK_TOOLBAR_ICONS);
 gtk_toolbar_set_tooltips(GTK_TOOLBAR(*tb), TRUE);
 gtk_container_set_border_width(GTK_CONTAINER(*tb), 5);
 gtk_toolbar_set_space_size(GTK_TOOLBAR(*tb), 5);
 style = gtk_widget_get_style(w);
 gcm = gdk_colormap_get_system();
 pix_new = gdk_pixmap_colormap_create_from_xpm_d
	 (w->window,gcm,&mask,&style->bg[GTK_STATE_NORMAL],(gchar **)xpm_new);
 pix = gtk_pixmap_new(pix_new, mask);
 gtk_toolbar_append_item(GTK_TOOLBAR(*tb), NULL, "New DB", "Private",pix,create_database,NULL);
 pix_new = gdk_pixmap_colormap_create_from_xpm_d
	 (w->window,gcm,&mask,&style->bg[GTK_STATE_NORMAL],(gchar **)xpm_open);
 pix = gtk_pixmap_new(pix_new, mask);
 gtk_toolbar_append_item(GTK_TOOLBAR(*tb), NULL, "Open DB", "Private",pix,load_database,NULL);
 pix_new = gdk_pixmap_colormap_create_from_xpm_d
	 (w->window,gcm,&mask,&style->bg[GTK_STATE_NORMAL],(gchar **)xpm_create);
 pix = gtk_pixmap_new(pix_new, mask);
 gtk_toolbar_append_item(GTK_TOOLBAR(*tb), NULL, "Create DB from file","Private",pix,create_DB_from_file,NULL);
 pix_new = gdk_pixmap_colormap_create_from_xpm_d
	 (w->window,gcm,&mask,&style->bg[GTK_STATE_NORMAL],(gchar **)xpm_save);
 pix = gtk_pixmap_new(pix_new, mask);
 gtk_toolbar_append_item(GTK_TOOLBAR(*tb), NULL, "Save DB to file", "Private",pix,save_database,NULL);
 pix_new = gdk_pixmap_colormap_create_from_xpm_d
	 (w->window,gcm,&mask,&style->bg[GTK_STATE_NORMAL],(gchar **)xpm_copy);
 pix = gtk_pixmap_new(pix_new, mask);
 gtk_toolbar_append_item(GTK_TOOLBAR(*tb), NULL, "Copy DB", "Private",pix,copy_database,NULL);
 pix_new = gdk_pixmap_colormap_create_from_xpm_d
	 (w->window,gcm,&mask,&style->bg[GTK_STATE_NORMAL],(gchar **)xpm_drop);
 pix = gtk_pixmap_new(pix_new, mask);
 gtk_toolbar_append_item(GTK_TOOLBAR(*tb), NULL, "Drop DB", "Private",pix,drop_database,NULL);
 gtk_toolbar_append_space(GTK_TOOLBAR(*tb));
 pix_new = gdk_pixmap_colormap_create_from_xpm_d
	 (w->window,gcm,&mask,&style->bg[GTK_STATE_NORMAL],(gchar **)xpm_sql);
 pix = gtk_pixmap_new(pix_new, mask);
 gtk_toolbar_append_item(GTK_TOOLBAR(*tb), NULL, "SQL Query Editor", "Private",pix,query_executor,NULL);
 pix_new = gdk_pixmap_colormap_create_from_xpm_d
	 (w->window,gcm,&mask,&style->bg[GTK_STATE_NORMAL],(gchar **)xpm_env);
 pix = gtk_pixmap_new(pix_new, mask);
 gtk_toolbar_append_item(GTK_TOOLBAR(*tb), NULL, "DB Environment", "Private",pix,env_dialog,NULL);
 gtk_toolbar_append_space(GTK_TOOLBAR(*tb));
 pix_new = gdk_pixmap_colormap_create_from_xpm_d
	 (w->window,gcm,&mask,&style->bg[GTK_STATE_NORMAL],(gchar **)xpm_fexec1);
 pix = gtk_pixmap_new(pix_new, mask);
 gtk_toolbar_append_item(GTK_TOOLBAR(*tb), NULL, "Fast Execute OpenDlg", "Private",pix,execute_fast,(gpointer)(1));
 pix_new = gdk_pixmap_colormap_create_from_xpm_d
	 (w->window,gcm,&mask,&style->bg[GTK_STATE_NORMAL],(gchar **)xpm_fexec2);
 pix = gtk_pixmap_new(pix_new, mask);
 gtk_toolbar_append_item(GTK_TOOLBAR(*tb), NULL, "Fast Execute Filename", "Private",pix,execute_fast,(gpointer)(2));
 pix_new = gdk_pixmap_colormap_create_from_xpm_d
	 (w->window,gcm,&mask,&style->bg[GTK_STATE_NORMAL],(gchar **)xpm_fexec3);
 pix = gtk_pixmap_new(pix_new, mask);
 gtk_toolbar_append_item(GTK_TOOLBAR(*tb), NULL, "Fast Execute Command", "Private",pix,execute_fast,(gpointer)(3));
 gtk_toolbar_append_space(GTK_TOOLBAR(*tb));
 pix_new = gdk_pixmap_colormap_create_from_xpm_d
	 (w->window,gcm,&mask,&style->bg[GTK_STATE_NORMAL],(gchar **)xpm_about);
 pix = gtk_pixmap_new(pix_new, mask);
 gtk_toolbar_append_item(GTK_TOOLBAR(*tb), NULL, "About", "Private",pix,about_box,NULL);
 pix_new = gdk_pixmap_colormap_create_from_xpm_d
	 (w->window,gcm,&mask,&style->bg[GTK_STATE_NORMAL],(gchar **)xpm_quit);
 pix = gtk_pixmap_new(pix_new, mask);
 gtk_toolbar_append_item(GTK_TOOLBAR(*tb), NULL, "Quit", "Private",pix,GTK_SIGNAL_FUNC(menu_quit),NULL);
}
